@@ -43,8 +43,10 @@ def douyutv_download(url, output_dir = '.', merge = True, info_only = False, **k
     headers = {
         'user-agent': 'Mozilla/5.0 (iPad; CPU OS 8_1_3 like Mac OS X) AppleWebKit/600.1.4 (KHTML, like Gecko) Version/8.0 Mobile/12B466 Safari/600.1.4'
     }
+    
+    url = re.sub(r'[w.]*douyu.com','m.douyu.com',url)
     html = get_content(url, headers)
-    room_id_patt = r'"room_id"\s*:\s*(\d+),'
+    room_id_patt = r'room_id\s*:\s*(\d+),'
     room_id = match1(html, room_id_patt)
     if room_id == "0":
         room_id = url[url.rfind('/')+1:]
